@@ -22,6 +22,7 @@ namespace loader
     ze_dditable_t* loaderZeDdiTable = nullptr;
     zet_dditable_t* loaderZetDdiTable = nullptr;
     zes_dditable_t* loaderZesDdiTable = nullptr;
+    zer_dditable_t *defaultZerDdiTable = nullptr;
     ///////////////////////////////////////////////////////////////////////////////
     context_t *context;
 
@@ -234,7 +235,7 @@ namespace loader
         }
 
         // Replace the original driver vector with the ordered one
-        *drivers = orderedDrivers;
+        *drivers = std::move(orderedDrivers);
 
         if (debugTraceEnabled) {
             std::string message = "driverOrdering: Drivers after ZEL_DRIVERS_ORDER:";
@@ -256,6 +257,7 @@ namespace loader
         for (auto &driver : *drivers) {
             uint32_t pCount = 0;
             std::vector<ze_driver_handle_t> driverHandles;
+            driver.pciOrderingRequested = loader::context->pciOrderingRequested;
             ze_result_t res = ZE_RESULT_SUCCESS;
             if (desc && driver.dditable.ze.Global.pfnInitDrivers) {
                 if (driver.initDriversStatus != ZE_RESULT_SUCCESS) {
@@ -322,21 +324,53 @@ namespace loader
                     continue;
                 }
             } else {
+                res = ZE_RESULT_ERROR_UNINITIALIZED;
                 if (debugTraceEnabled) {
-                    std::string message = "driverSorting " + driver.name + " zeDriverGet and zeInitDrivers not supported, skipping driver";
+                    std::string message = "driverSorting " + driver.name + " zeDriverGet and zeInitDrivers not supported, skipping driver with error ";
                     debug_trace_message(message, loader::to_string(res));
                 }
                 continue;
             }
 
             for (auto handle : driverHandles) {
+                uint32_t extensionCount = 0;
+                if (driver.zerddiInitResult == ZE_RESULT_SUCCESS)
+                    driver.zerDriverHandle = handle;
+                ze_result_t res = driver.dditable.ze.Driver.pfnGetExtensionProperties(handle, &extensionCount, nullptr);
+                if (res != ZE_RESULT_SUCCESS) {
+                    if (loader::context->debugTraceEnabled) {
+                        std::string message = "driverSorting " + driver.name + " failed, zeDriverGetExtensionProperties returned ";
+                        debug_trace_message(message, loader::to_string(res));
+                    }
+                    return res;
+                }
+                std::vector<ze_driver_extension_properties_t> extensionProperties(extensionCount);
+                res = driver.dditable.ze.Driver.pfnGetExtensionProperties(handle, &extensionCount, extensionProperties.data());
+                if (res != ZE_RESULT_SUCCESS) {
+                    if (loader::context->debugTraceEnabled) {
+                        std::string message = "driverSorting " + driver.name + " failed, zeDriverGetExtensionProperties returned ";
+                        debug_trace_message(message, loader::to_string(res));
+                    }
+                    return res;
+                }
+                if (extensionCount > 0) {
+                    for (uint32_t extIndex = 0; extIndex < extensionCount; extIndex++) {
+                        if (strcmp(extensionProperties[extIndex].name, ZE_DRIVER_DDI_HANDLES_EXT_NAME) == 0 && (!(extensionProperties[extIndex].version >= ZE_DRIVER_DDI_HANDLES_EXT_VERSION_1_1))) {
+                            // Driver supports DDI Handles but not the required version for ZER APIs so set the driverHandle to nullptr
+                            driver.zerDriverHandle = nullptr;
+                            driver.zerDriverDDISupported = false;
+                            break;
+                        }
+                    }
+
+                }
                 driver.properties = {};
                 driver.properties.stype = ZE_STRUCTURE_TYPE_DRIVER_DDI_HANDLES_EXT_PROPERTIES;
                 driver.properties.pNext = nullptr;
                 ze_driver_properties_t driverProperties = {};
                 driverProperties.stype = ZE_STRUCTURE_TYPE_DRIVER_PROPERTIES;
                 driverProperties.pNext = &driver.properties;
-                ze_result_t res = driver.dditable.ze.Driver.pfnGetProperties(handle, &driverProperties);
+                res = driver.dditable.ze.Driver.pfnGetProperties(handle, &driverProperties);
                 if (res != ZE_RESULT_SUCCESS) {
                     if (debugTraceEnabled) {
                         std::string message = "driverSorting " + driver.name + " failed, zeDriverGetProperties returned ";
@@ -345,6 +379,19 @@ namespace loader
                     continue;
                 }
                 driver.driverDDIHandleSupportQueried = true;
+                
+                if (!(driver.properties.flags & ZE_DRIVER_DDI_HANDLE_EXT_FLAG_DDI_HANDLE_EXT_SUPPORTED) || !loader::context->driverDDIPathDefault) {
+                    if (debugTraceEnabled) {
+                        std::string message = "driverSorting: Driver DDI Handles Not Supported for " + driver.name;
+                        debug_trace_message(message, "");
+                    }
+                } else {
+                    if (debugTraceEnabled) {
+                        std::string message = "driverSorting: Driver DDI Handles Supported for " + driver.name;
+                        debug_trace_message(message, "");
+                    }
+                }
+                
                 uint32_t deviceCount = 0;
                 res = driver.dditable.ze.Device.pfnGet( handle, &deviceCount, nullptr );
                 if( ZE_RESULT_SUCCESS != res ) {
@@ -372,6 +419,7 @@ namespace loader
                 }
                 bool integratedGPU = false;
                 bool discreteGPU = false;
+                bool npu = false;
                 bool other = false;
                 for( auto device : deviceHandles ) {
                     ze_device_properties_t deviceProperties = {};
@@ -391,11 +439,17 @@ namespace loader
                         } else {
                             discreteGPU = true;
                         }
+                    } else  if (deviceProperties.type == ZE_DEVICE_TYPE_VPU) {
+                        npu = true;
                     } else {
                         other = true;
                     }
                 }
-                if (integratedGPU && discreteGPU && other) {
+                if (driver.driverType == ZEL_DRIVER_TYPE_NPU && npu == false) {
+                    // Driver was forced to NPU but no NPU devices found, skip updating type.
+                    continue;
+                }
+                if (integratedGPU && discreteGPU && (other || npu)) {
                     driver.driverType = ZEL_DRIVER_TYPE_MIXED;
                 } else if (integratedGPU && discreteGPU) {
                     driver.driverType = ZEL_DRIVER_TYPE_GPU;
@@ -403,6 +457,8 @@ namespace loader
                     driver.driverType = ZEL_DRIVER_TYPE_INTEGRATED_GPU;
                 } else if (discreteGPU) {
                     driver.driverType = ZEL_DRIVER_TYPE_DISCRETE_GPU;
+                } else if (npu) {
+                    driver.driverType = ZEL_DRIVER_TYPE_NPU;
                 } else if (other) {
                     driver.driverType = ZEL_DRIVER_TYPE_OTHER;
                 }
@@ -426,202 +482,113 @@ namespace loader
         return true;
     }
 
-    /**
-     * @brief Checks and initializes drivers based on the provided flags and descriptors.
-     *
-     * This function performs the following operations:
-     * 1. If debug tracing is enabled, logs the input parameters.
-     * 2. If `zeInitDrivers` is not supported by the driver and it is called first, returns `ZE_RESULT_ERROR_UNINITIALIZED`.
-     * 3. Determines the appropriate driver vector (`zeDrivers` or `zesDrivers`) based on the input parameters.
-     * 4. Iterates over the drivers and attempts to initialize each driver:
-     *    - If initialization fails and the driver is not in use, removes the driver from the list.
-     *    - If the number of drivers becomes one and interception is not forced, sets the `requireDdiReinit` flag to true.
-     *    - If the initialization fails and `return_first_driver_result` is true, returns the result immediately.
-     *    - If initialization succeeds, marks the driver as in use.
-     * 5. If no drivers are left, returns `ZE_RESULT_ERROR_UNINITIALIZED`.
-     * 6. Returns `ZE_RESULT_SUCCESS` if at least one driver is successfully initialized.
-     *
-     * @param flags Initialization flags.
-     * @param desc Driver type descriptor (optional).
-     * @param globalInitStored Pointer to global DDI table for initialization.
-     * @param sysmanGlobalInitStored Pointer to Sysman global DDI table for initialization.
-     * @param requireDdiReinit Pointer to a boolean flag indicating if DDI reinitialization is required.
-     * @param sysmanOnly Boolean flag indicating if only Sysman drivers should be checked.
-     * @return `ZE_RESULT_SUCCESS` if at least one driver is successfully initialized, otherwise an appropriate error code.
-     */
-    ze_result_t context_t::check_drivers(ze_init_flags_t flags, ze_init_driver_type_desc_t* desc, ze_global_dditable_t *globalInitStored, zes_global_dditable_t *sysmanGlobalInitStored, bool *requireDdiReinit, bool sysmanOnly) {
+    ze_result_t context_t::init_driver(driver_t &driver, ze_init_flags_t flags, ze_init_driver_type_desc_t* desc) {
+        bool loadDriver = false;
         if (debugTraceEnabled) {
-            if (desc) {
-                std::string message = "check_drivers(" + std::string("desc->flags=") + loader::to_string(desc) + ")";
-                debug_trace_message(message, "");
-            } else {
-                std::string message = "check_drivers(" + std::string("flags=") + loader::to_string(flags) + ")";
-                debug_trace_message(message, "");
-            }
+            std::string message = "Initializing driver " + driver.name + " with type " + std::to_string(driver.driverType);\
+            debug_trace_message(message, "");
         }
-        // If zeInitDrivers is not supported by this driver, but zeInitDrivers is called first, then return uninitialized.
-        if (desc && !loader::context->initDriversSupport) {
-            if (debugTraceEnabled) {
-                std::string message = "zeInitDrivers called first, but not supported by driver, returning uninitialized.";
-                debug_trace_message(message, "");
-            }
-            return ZE_RESULT_ERROR_UNINITIALIZED;
-        }
-
-
-        bool return_first_driver_result=false;
-        std::string initName = "zeInit";
-        driver_vector_t *drivers = &zeDrivers;
-        // If desc is set, then this is zeInitDrivers.
-        if (desc) {
-            initName = "zeInitDrivers";
-        }
-        // If this is sysmanOnly check_drivers, then zesInit is being called and we need to use zesDrivers.
-        if (sysmanOnly) {
-            drivers = &zesDrivers;
-            initName = "zesInit";
-        }
-        if(drivers->size()==1) {
-            return_first_driver_result=true;
-        }
-        bool pciOrderingRequested = getenv_tobool( "ZE_ENABLE_PCI_ID_DEVICE_ORDER" );
-        loader::context->instrumentationEnabled = getenv_tobool( "ZET_ENABLE_PROGRAM_INSTRUMENTATION" );
-
-        for(auto it = drivers->begin(); it != drivers->end(); )
-        {
-            it->pciOrderingRequested = pciOrderingRequested;
-            std::string freeLibraryErrorValue;
-            ze_result_t result = init_driver(*it, flags, desc, globalInitStored, sysmanGlobalInitStored, sysmanOnly);
-            if(result != ZE_RESULT_SUCCESS) {
-                // If the driver has already been init and handles are to be read, then this driver cannot be removed from the list.
-                // Also, if any driver supports zeInitDrivers, then no driver can be removed to allow for different sets of drivers.
-                if (!it->driverInuse && !loader::context->initDriversSupport) {
-                    if (debugTraceEnabled) {
-                        std::string errorMessage = "Check Drivers Failed on " + it->name + " , driver will be removed. " + initName + " failed with ";
-                        debug_trace_message(errorMessage, loader::to_string(result));
-                    }
-                    it = drivers->erase(it);
-                    // If the number of drivers is now ==1, then we need to reinit the ddi tables to pass through.
-                    // If ZE_ENABLE_LOADER_INTERCEPT is set to 1, then even if drivers were removed, don't reinit the ddi tables.
-                    if (drivers->size() == 1 && !loader::context->forceIntercept) {
-                        *requireDdiReinit = true;
-                    }
-                } else {
-                    it++;
+        if ((!desc && (flags == 0 || flags & ZE_INIT_FLAG_GPU_ONLY)) || (desc && desc->flags & ZE_INIT_DRIVER_TYPE_FLAG_GPU)) {
+            if (driver.driverType == ZEL_DRIVER_TYPE_GPU || driver.driverType == ZEL_DRIVER_TYPE_DISCRETE_GPU || driver.driverType == ZEL_DRIVER_TYPE_INTEGRATED_GPU) {
+                if (debugTraceEnabled) {
+                    std::string message = "init driver " + driver.name + " found GPU Supported Driver.";
+                    debug_trace_message(message, "");
                 }
-                if(return_first_driver_result)
-                    return result;
-            } else {
-                // If this is a single driver system, then the first success for this driver needs to be set.
-                it->driverInuse = true;
-                it++;
+                loadDriver = true;
+            }
+        }
+        if ((!desc && (flags == 0 || flags & ZE_INIT_FLAG_VPU_ONLY)) || (desc && desc->flags & ZE_INIT_DRIVER_TYPE_FLAG_NPU)) {
+            if (driver.driverType == ZEL_DRIVER_TYPE_NPU || driver.driverType == ZEL_DRIVER_TYPE_OTHER) {
+                if (debugTraceEnabled) {
+                    std::string message = "init driver " + driver.name + " found VPU/NPU Supported Driver.";
+                    debug_trace_message(message, "");
+                }
+                loadDriver = true;
             }
         }
 
-        if(drivers->size() == 0)
+        loadDriver = !driver.handle && driver.customDriver ? true : loadDriver;
+
+        if (loadDriver && !driver.handle) {
+            auto handle = LOAD_DRIVER_LIBRARY( driver.name.c_str() );
+            if( NULL != handle )
+            {
+                driver.handle = handle;
+            } else {
+                std::string loadLibraryErrorValue;
+                GET_LIBRARY_ERROR(loadLibraryErrorValue);
+                if (debugTraceEnabled) {
+                    std::string errorMessage = "init driver " + driver.name + " failed, Load Library of " + driver.name + " failed with ";
+                    debug_trace_message(errorMessage, loadLibraryErrorValue);
+                }
+                return ZE_RESULT_ERROR_UNINITIALIZED;
+            }
+        }
+
+        if (driver.handle && !driver.ddiInitialized) {
+            auto res = loader::zeloaderInitDriverDDITables(&driver);
+            if (res != ZE_RESULT_SUCCESS) {
+                if (debugTraceEnabled) {
+                    std::string message = "init driver " + driver.name + " failed, zeloaderInitDriverDDITables returned ";
+                    debug_trace_message(message, loader::to_string(res));
+                }
+                driver.zeddiInitResult = res;
+            } else {
+                driver.zeddiInitResult = ZE_RESULT_SUCCESS;
+            }
+            res = loader::zesloaderInitDriverDDITables(&driver);
+            if (res != ZE_RESULT_SUCCESS) {
+                if (debugTraceEnabled) {
+                    std::string message = "init driver " + driver.name + " failed, zesloaderInitDriverDDITables returned ";
+                    debug_trace_message(message, loader::to_string(res));
+                }
+                driver.zesddiInitResult = res;
+            } else {
+                driver.zesddiInitResult = ZE_RESULT_SUCCESS;
+            }
+            res = loader::zetloaderInitDriverDDITables(&driver);
+            if (res != ZE_RESULT_SUCCESS) {
+                if (debugTraceEnabled) {
+                    std::string message = "init driver " + driver.name + " failed, zetloaderInitDriverDDITables returned ";
+                    debug_trace_message(message, loader::to_string(res));
+                }
+                driver.zetddiInitResult = res;
+            } else {
+                driver.zetddiInitResult = ZE_RESULT_SUCCESS;
+            }
+            res = loader::zerloaderInitDriverDDITables(&driver);
+            if (res != ZE_RESULT_SUCCESS) {
+                if (debugTraceEnabled) {
+                    std::string message = "init driver " + driver.name + " failed, zerloaderInitDriverDDITables returned ";
+                    debug_trace_message(message, loader::to_string(res));
+                }
+                driver.zerddiInitResult = res;
+                driver.zerDriverHandle = nullptr;
+            } else {
+                driver.zerddiInitResult = ZE_RESULT_SUCCESS;
+            }
+            driver.ddiInitialized = true;
+        }
+
+        if (!driver.handle && !driver.ddiInitialized) {
+            if (debugTraceEnabled) {
+                std::string message = "init driver " + driver.name + " does not match the requested flags or desc, skipping driver.";
+                debug_trace_message(message, "");
+            }
             return ZE_RESULT_ERROR_UNINITIALIZED;
+        }
 
         return ZE_RESULT_SUCCESS;
     }
 
-    ze_result_t context_t::init_driver(driver_t &driver, ze_init_flags_t flags, ze_init_driver_type_desc_t* desc, ze_global_dditable_t *globalInitStored, zes_global_dditable_t *sysmanGlobalInitStored, bool sysmanOnly) {
-        if (sysmanOnly) {
-            auto getTable = reinterpret_cast<zes_pfnGetGlobalProcAddrTable_t>(
-                GET_FUNCTION_PTR(driver.handle, "zesGetGlobalProcAddrTable"));
-            if(!getTable) {
-                if (debugTraceEnabled) {
-                    std::string errorMessage = "init driver " + driver.name + " failed, zesGetGlobalProcAddrTable function pointer null. Returning ";
-                    debug_trace_message(errorMessage, loader::to_string(ZE_RESULT_ERROR_UNINITIALIZED));
-                }
-                return ZE_RESULT_ERROR_UNINITIALIZED;
-            }
-
-            zes_global_dditable_t global;
-            auto getTableResult = getTable(this->configured_version, &global);
-            if(getTableResult != ZE_RESULT_SUCCESS) {
-                if (debugTraceEnabled) {
-                    std::string errorMessage = "init driver " + driver.name + " failed, zesGetGlobalProcAddrTable() failed with ";
-                    debug_trace_message(errorMessage, loader::to_string(getTableResult));
-                }
-                return ZE_RESULT_ERROR_UNINITIALIZED;
-            }
-
-            if(nullptr == global.pfnInit) {
-                if (debugTraceEnabled) {
-                    std::string errorMessage = "init driver " + driver.name + " failed, zesInit function pointer null. Returning ";
-                    debug_trace_message(errorMessage, loader::to_string(ZE_RESULT_ERROR_UNINITIALIZED));
-                }
-                return ZE_RESULT_ERROR_UNINITIALIZED;
-            }
-
-            // Use the previously init ddi table pointer to zesInit to allow for intercept of the zesInit calls
-            ze_result_t res = sysmanGlobalInitStored->pfnInit(flags);
-            // Verify that this driver successfully init in the call above.
-            if (driver.initSysManStatus != ZE_RESULT_SUCCESS) {
-                res = driver.initSysManStatus;
-            }
-            if (debugTraceEnabled) {
-                std::string message = "init driver " + driver.name + " zesInit(" + loader::to_string(flags) + ") returning ";
-                debug_trace_message(message, loader::to_string(res));
-            }
-            return res;
-        } else {
-            if (!desc) {
-                auto pfnInit = driver.dditable.ze.Global.pfnInit;
-                if(nullptr == pfnInit || globalInitStored->pfnInit == nullptr) {
-                    if (debugTraceEnabled) {
-                        std::string errorMessage = "init driver " + driver.name + " failed, zeInit function pointer null. Returning ";
-                        debug_trace_message(errorMessage, loader::to_string(ZE_RESULT_ERROR_UNINITIALIZED));
-                    }
-                    return ZE_RESULT_ERROR_UNINITIALIZED;
-                }
-
-                // Use the previously init ddi table pointer to zeInit to allow for intercept of the zeInit calls
-                ze_result_t res = globalInitStored->pfnInit(flags);
-                // Verify that this driver successfully init in the call above.
-                if (res != ZE_RESULT_SUCCESS || driver.initStatus != ZE_RESULT_SUCCESS) {
-                    if (driver.initStatus != ZE_RESULT_SUCCESS)
-                        res = driver.initStatus;
-                    if (debugTraceEnabled) {
-                        std::string message = "init driver (global ddi) " + driver.name + " zeInit(" + loader::to_string(flags) + ") returning ";
-                        debug_trace_message(message, loader::to_string(res));
-                    }
-                    return res;
-                }
-            } else {
-                auto pfnInitDrivers = driver.dditable.ze.Global.pfnInitDrivers;
-                if(nullptr == pfnInitDrivers || globalInitStored->pfnInitDrivers == nullptr) {
-                    if (debugTraceEnabled) {
-                        std::string errorMessage = "init driver " + driver.name + " failed, pfnInitDrivers function pointer null. Returning ";
-                        debug_trace_message(errorMessage, loader::to_string(ZE_RESULT_ERROR_UNINITIALIZED));
-                    }
-                    return ZE_RESULT_ERROR_UNINITIALIZED;
-                }
-
-                uint32_t pCount = 0;
-                // Use the previously init ddi table pointer to zeInitDrivers to allow for intercept of the zeInitDrivers calls
-                ze_result_t res = globalInitStored->pfnInitDrivers(&pCount, nullptr, desc);
-                // Verify that this driver successfully init in the call above.
-                if (res != ZE_RESULT_SUCCESS || driver.initDriversStatus != ZE_RESULT_SUCCESS) {
-                    if (driver.initDriversStatus != ZE_RESULT_SUCCESS)
-                        res = driver.initDriversStatus;
-                    if (debugTraceEnabled) {
-                        std::string message = "init driver (global ddi) " + driver.name + " zeInitDrivers(" + loader::to_string(desc) + ") returning ";
-                        debug_trace_message(message, loader::to_string(res));
-                    }
-                    return res;
-                }
-            }
-            return ZE_RESULT_SUCCESS;
-        }
-    }
-
     ///////////////////////////////////////////////////////////////////////////////
     ze_result_t context_t::init()
     {
         if (driverEnvironmentQueried) {
             return ZE_RESULT_SUCCESS;
         }
+        loader::context->instrumentationEnabled = getenv_tobool( "ZET_ENABLE_PROGRAM_INSTRUMENTATION" );
+        loader::context->pciOrderingRequested = getenv_tobool( "ZE_ENABLE_PCI_ID_DEVICE_ORDER" );
         loader::loaderDispatch = new ze_handle_t();
         loader::loaderDispatch->pCore = new ze_dditable_driver_t();
         loader::loaderDispatch->pCore->version = ZE_API_VERSION_CURRENT;
@@ -632,9 +599,13 @@ namespace loader
         loader::loaderDispatch->pSysman = new zes_dditable_driver_t();
         loader::loaderDispatch->pSysman->version = ZE_API_VERSION_CURRENT;
         loader::loaderDispatch->pSysman->isValidFlag = 1;
+        loader::loaderDispatch->pRuntime = new zer_dditable_driver_t();
+        loader::loaderDispatch->pRuntime->version = ZE_API_VERSION_CURRENT;
+        loader::loaderDispatch->pRuntime->isValidFlag = 1;
         loader::loaderZeDdiTable = new ze_dditable_t();
         loader::loaderZetDdiTable = new zet_dditable_t();
         loader::loaderZesDdiTable = new zes_dditable_t();
+        loader::defaultZerDdiTable = new zer_dditable_t();
         debugTraceEnabled = getenv_tobool( "ZE_ENABLE_LOADER_DEBUG_TRACE" );
         // DDI Driver Extension Path is enabled by default.
         // This can be overridden by the environment variable ZE_ENABLE_LOADER_DRIVER_DDI_PATH.
@@ -705,30 +676,39 @@ namespace loader
             }
         }
 
-        for( auto name : discoveredDrivers )
+        for( const auto& driverInfo : discoveredDrivers )
         {
-            auto handle = LOAD_DRIVER_LIBRARY( name.c_str() );
-            if( NULL != handle )
-            {
-                if (debugTraceEnabled) {
-                    std::string message = "Loading Driver " + name + " succeeded";
+            if (discoveredDrivers.size() == 1) {
+                auto handle = LOAD_DRIVER_LIBRARY( driverInfo.path.c_str() );
+                if( NULL != handle )
+                {
+                    if (debugTraceEnabled) {
+                        std::string message = "Loading Driver " + driverInfo.path + " succeeded";
 #if !defined(_WIN32) && !defined(ANDROID)
-                    // TODO: implement same message for windows, move dlinfo to ze_util.h as a macro
-                    struct link_map *dlinfo_map;
-                    if (dlinfo(handle, RTLD_DI_LINKMAP, &dlinfo_map) == 0) {
-                        message += " from: " + std::string(dlinfo_map->l_name);
-                    }
+                        // TODO: implement same message for windows, move dlinfo to ze_util.h as a macro
+                        struct link_map *dlinfo_map;
+                        if (dlinfo(handle, RTLD_DI_LINKMAP, &dlinfo_map) == 0) {
+                            message += " from: " + std::string(dlinfo_map->l_name);
+                        }
 #endif
-                    debug_trace_message(message, "");
+                        debug_trace_message(message, "");
+                    }
+                    allDrivers.emplace_back();
+                    allDrivers.rbegin()->handle = handle;
+                    allDrivers.rbegin()->name = driverInfo.path;
+                    allDrivers.rbegin()->customDriver = driverInfo.customDriver;
+                } else if (debugTraceEnabled) {
+                    GET_LIBRARY_ERROR(loadLibraryErrorValue);
+                    std::string errorMessage = "Load Library of " + driverInfo.path + " failed with ";
+                    debug_trace_message(errorMessage, loadLibraryErrorValue);
+                    loadLibraryErrorValue.clear();
                 }
+            } else {
                 allDrivers.emplace_back();
-                allDrivers.rbegin()->handle = handle;
-                allDrivers.rbegin()->name = name;
-            } else if (debugTraceEnabled) {
-                GET_LIBRARY_ERROR(loadLibraryErrorValue);
-                std::string errorMessage = "Load Library of " + name + " failed with ";
-                debug_trace_message(errorMessage, loadLibraryErrorValue);
-                loadLibraryErrorValue.clear();
+                allDrivers.rbegin()->handle = nullptr;
+                allDrivers.rbegin()->name = driverInfo.path;
+                allDrivers.rbegin()->customDriver = driverInfo.customDriver;
+                allDrivers.rbegin()->driverType = driverInfo.driverType;
             }
         }
         if(allDrivers.size()==0){
@@ -807,6 +787,10 @@ namespace loader
 
         driverEnvironmentQueried = true;
 
+        // Set default driver zer DDI table to the first driver in the list before sorting.
+        // Leave the zer Driver Handle as nullptr until init when the drivers are sorted and initialized.
+        loader::defaultZerDdiTable = &loader::context->zeDrivers.front().dditable.zer;
+
         zel_logger->log_info("zeInit succeeded");
         return ZE_RESULT_SUCCESS;
     };
@@ -859,6 +843,7 @@ namespace loader
             loader_driver_ddi::zeDestroyDDiDriverTables(loader::loaderDispatch->pCore);
             loader_driver_ddi::zetDestroyDDiDriverTables(loader::loaderDispatch->pTools);
             loader_driver_ddi::zesDestroyDDiDriverTables(loader::loaderDispatch->pSysman);
+            loader_driver_ddi::zerDestroyDDiDriverTables(loader::loaderDispatch->pRuntime);
             delete loader::loaderDispatch;
             loader::loaderDispatch = nullptr;
         }
