@@ -28,14 +28,14 @@ zeLoaderInit()
 
 ///////////////////////////////////////////////////////////////////////////////
 /// @brief Exported function for verifying usable L0 Drivers for Loader to report
-///
+/// @deprecated This function is deprecated and will be removed in a future release.
 /// @returns
 ///     - ::ZE_RESULT_SUCCESS
 ///     - ::ZE_RESULT_ERROR_UNINITIALIZED
 ZE_DLLEXPORT ze_result_t ZE_APICALL
 zelLoaderDriverCheck(ze_init_flags_t flags, ze_init_driver_type_desc_t* desc, ze_global_dditable_t *globalInitStored, zes_global_dditable_t *sysmanGlobalInitStored, bool *requireDdiReinit, bool sysmanOnly)
 {
-    return loader::context->check_drivers(flags, desc, globalInitStored, sysmanGlobalInitStored, requireDdiReinit, sysmanOnly);
+    return ZE_RESULT_SUCCESS;
 }
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -60,7 +60,7 @@ zelLoaderGetContext() {
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-/// @brief Internal function for Setting the ddi table for the Tracing Layer.
+/// @brief Internal function for Setting the ZE ddi table for the Tracing Layer.
 ///
 ZE_DLLEXPORT ze_result_t ZE_APICALL
 zelLoaderTracingLayerInit(std::atomic<ze_dditable_t *> &zeDdiTable) {
@@ -68,6 +68,15 @@ zelLoaderTracingLayerInit(std::atomic<ze_dditable_t *> &zeDdiTable) {
     return ZE_RESULT_SUCCESS;
 }
 
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Internal function for Setting the ZER ddi table for the Tracing Layer.
+///
+ZE_DLLEXPORT ze_result_t ZE_APICALL
+zelLoaderZerTracingLayerInit(std::atomic<zer_dditable_t *> &zerDdiTable) {
+    zerDdiTable.store(&loader::context->tracing_dditable.zer);
+    return ZE_RESULT_SUCCESS;
+}
+
 ZE_DLLEXPORT ze_result_t ZE_APICALL
 zelLoaderGetVersionsInternal(
    size_t *num_elems,                     //Pointer to num versions to get.  
@@ -83,6 +92,19 @@ zelLoaderGetVersionsInternal(
     return ZE_RESULT_SUCCESS;
 }
 
+ZE_DLLEXPORT ze_result_t ZE_APICALL
+zelLoaderGetVersion(zel_component_version_t *version)
+{
+    if(version == nullptr)
+        return ZE_RESULT_ERROR_INVALID_NULL_POINTER;
+    string_copy_s(version->component_name, "loader", ZEL_COMPONENT_STRING_SIZE);
+    version->spec_version = ZE_API_VERSION_CURRENT;
+    version->component_lib_version.major = LOADER_VERSION_MAJOR;
+    version->component_lib_version.minor = LOADER_VERSION_MINOR;
+    version->component_lib_version.patch = LOADER_VERSION_PATCH;
+
+    return ZE_RESULT_SUCCESS;
+}
 
 ZE_DLLEXPORT ze_result_t ZE_APICALL
 zelLoaderTranslateHandleInternal(
