@@ -17,6 +17,7 @@ struct dditable_t
     ze_dditable_t   ze;
     zet_dditable_t  zet;
     zes_dditable_t  zes;
+    zer_dditable_t  zer;
 };
 
 namespace loader {
@@ -34,6 +35,7 @@ public:
     ze_dditable_driver_t *pCore;
     zet_dditable_driver_t *pTools;
     zes_dditable_driver_t *pSysman;
+    zer_dditable_driver_t *pRuntime;
     handle_t    handle;
     dditable_t* dditable;
 
@@ -45,6 +47,7 @@ public:
         pCore = loader::loaderDispatch->pCore;
         pTools = loader::loaderDispatch->pTools;
         pSysman = loader::loaderDispatch->pSysman;
+        pRuntime = loader::loaderDispatch->pRuntime;
     }
 
     ~object_t() = default;
